@@ -24,8 +24,12 @@ from KeePassLib.Keys import CompositeKey, KcpPassword, InvalidCompositeKeyExcept
 from KeePassLib.Security import ProtectedString
 from KeePassLib.Serialization import IOConnectionInfo
 from PassXYZLib import PxDefs, PxDatabase, PxLibInfo
+from PassXYZ.Services import PxKeyProvider
 
 
+def get_username(filename):
+    return PxDefs.GetUserNameFromDataFile(filename)
+
 def get_homepath():
     config_file = str(Path.home())+'/.kpclibdb/kpclibpy.ini'
 
@@ -71,6 +75,14 @@ class KeePass:
         self._user_name = None
         self.is_hidden = True
 
+    @property
+    def version1(self):
+        """
+        ReadOnly property to represent the version of PassXYZ
+        """
+        return PxKeyProvider.Version
+
+
     @property
     def version(self):
         """
@@ -332,12 +344,13 @@ class KeePass:
         """
         self._db = PxDatabase()
         try:
-            self._db.DefaultFolder = get_homepath()
+            homepath = get_homepath()
+            self._db.DefaultFolder = homepath
             self._db.Open(filename, password)
-        except InvalidCompositeKeyException:
+        except InvalidCompositeKeyException as ex:
+            cprint("connect: The composite key is invalid!\npath={}, file={}\n{}".format(homepath, filename, ex), "red")
             self.close()
             self._db = None
-            cprint("open: The composite key is invalid!", "red")
             return
 
     def open(self, db_path, password, logger):
@@ -383,4 +396,4 @@ class KeePass:
             if self._db.MoveEntry(src_entry, dst_group):
                 print("Moved {} to {}".format(src_entry.get_Name(), dst_group.get_Name()))
             else:
-                print("Cannot move {} to {}".format(src_entry.get_Name(), dst_group.get_Name()))
\ No newline at end of file
+                print("Cannot move {} to {}".format(src_entry.get_Name(), dst_group.get_Name()))
